package com.example.julian.endlessroll.main.screens;

import android.widget.RelativeLayout;

import com.example.julian.endlessroll.R;
import com.example.julian.endlessroll.levels.Level;
import com.example.julian.endlessroll.levels.LevelPack;
import com.example.julian.endlessroll.main.GameActivity;
import com.example.julian.endlessroll.main.GameHandler;
import com.example.julian.endlessroll.main.MyGlSurfaceView;
import com.example.julian.endlessroll.main.game.Game;
import com.example.julian.endlessroll.main.tutorial.BreakPoint;
import com.example.julian.endlessroll.views.TopBarData;

import java.util.List;

/**
 * Created by Julian on 08.02.2016.
 */
public class GameScreen extends GLScreen<RelativeLayout> {

    private GameActivity activity;
    private Game game;

    public GameScreen(TopBarData topBarData, MyGlSurfaceView glSurfaceView) throws Exception {
        super(ScreenType.GAME, topBarData.getGameActivity(), R.layout.game, glSurfaceView);
        this.activity = topBarData.getGameActivity();
        game = new Game(gameViewHandler, topBarData);
        glView.addRendering(game);
    }

    @Override
    public void prepareToBeShown() {
        glView.setCurrentRendering(game);
        game.resetViews();
    }

    public void onPause() {
        game.tryToPause();
    }

    public void onResume(){
        game.setRunning();
    }

    @Override
    public void onBackKeyDown() {
            game.tryToPause();
    }

    public void startGame(LevelPack levelPack, Level level) {
        game.startGame(levelPack, level);
    }

    public GameHandler getGameViewHandler() {
        return gameViewHandler;
    }

    private GameHandler gameViewHandler = new GameHandler() {

        @Override
        public void startInUiThread(Runnable runnable) {
            activity.runOnUiThread(runnable);
        }

        @Override
        public void toScreen(ScreenType screen) {
            glView.setCurrentRendering(null);
            activity.flipToScreen(screen);
        }

        @Override
        public RelativeLayout getRootLayout() {
            return layout;
        }

        @Override
        public void showTutorialScreen(List<BreakPoint> breakPoints) {
            activity.showTutorialScreen(breakPoints);
        }

        @Override
        public void onException(Exception e) {
            activity.onException(e);
        }
    };

}
